@@ -105,6 +105,19 @@ def diab_user_option(f):
                         callback=callback)(f)
 
 
+def diab_dir_option(f):
+    def callback(ctx, param, value):
+        state: DartContext = ctx.ensure_object(DartContext)
+        if value is not None:
+            state.dart_env.default_env.set_data_dir(value)
+        return value
+    return click.option('--diab-dir',
+                        is_eager=False,
+                        expose_value=False,
+                        help='Set working directory for local or remote deployment of Dart-in-a-Box.',
+                        callback=callback)(f)
+
+
 def diab_version_option(f):
     def callback(ctx, param, value):
         state: DartContext = ctx.ensure_object(DartContext)
@@ -531,6 +544,7 @@ def dart_options(f):
     f = remote_deployment_option(f)
     f = tst_user_option(f)
     f = diab_user_option(f)
+    f = diab_dir_option(f)
     f = diab_version_option(f)
     f = local_deployment_option(f)
     f = aws_env_option(f)
